#!/bin/sh
# merge_cond.sh -- conditional merge script
# Findmerge is run 1st (in foreground) to determine if a merge is needed,
# if so, a background process is started to do the merge, if not, the
# user is informed via a non=blocking pop-up.
#
# $1 is the 'to' version
# $2 is the 'from' clause, e.g. '-flatest' or '-fver /main/10'
# $3 is the pathname of the terminal emulator script
#
TERM_EM="$3"

TMP="/tmp/merge.$$"
if cleartool findmerge "$1" $2 -whynot -print -log /dev/null >$TMP ; then
    # No errors
    if  grep "マージが必要" $TMP >/dev/null ; then
	# Needs merge
	# TRANSLATE quoted string after -prompt switch
	clearprompt yes_no -default yes -prefer_gui -prompt \
	"マージでは､完全に自動化したマージ (非グラフィック) を最初に試行できます。
	マージの競合により､ユーザーの介入が必要な場合は､マージが停止
	され、グラフィカルなマージ ツールが呼び出されます。

	最初に自動マージを行いますか?"

	st=$?
	if [ $st = 2 ] ; then
	    rm -f $TMP
	    exit 1
	elif [ $st = 0 ] ; then
	    # yes, do a -merge -gmerge
	    $TERM_EM NO_MORE "cleartool findmerge \"$1\" $2 -merge -gmerge -whynot -log /dev/null"
	else
	    # no, plain -gmerge
	    # Ask about -qall option
	    # TRANSLATE quoted string after -prompt switch
	    clearprompt yes_no -default yes -prefer_gui -prompt \
	    "グラフィカル マージ ツールは､競合していない差分に関して
	    自動的に決定するか、ユーザーに決定をゆだねることが
	    できます。競合しないすべての差分に関して､マージ
	    ツールを使用して自動的に決定しますか?"

	    st=$?
	    if [ $st = 2 ] ; then
		rm -f $TMP
		exit 1
	    elif [ $st = 0 ] ; then
		# yes, don't use -qall
	        cleartool findmerge "$1" $2 -gmerge -whynot -log /dev/null &
	    else
		# user wants to query all
		cleartool findmerge "$1" $2 -qall -gmerge -whynot -log \
						/dev/null &
		fi
	fi
	exit 0
    else
	# Doesn't need merge
	(clearprompt proceed -mask proceed \
		-type warning -prompt "`cat $TMP`" -prefer_gui
	rm -f $TMP ) &
	exit 0
    fi
else
   # Error
   rm -f $TMP
   exit 1
fi
